@@ -3,317 +3,357 @@
     <name>MainWindow</name>
     <message>
         <location filename="mainwindow.ui" line="20"/>
+        <location filename="ui_mainwindow.h" line="392"/>
         <source>Boot Repair</source>
-        <translation type="unfinished"/>
+        <translation>बूट सुधार</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="39"/>
+        <location filename="ui_mainwindow.h" line="393"/>
         <source>Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
-        <translation type="unfinished"/>
+        <translation>बूट सुधार - ESP (EFI सिस्टम विभाजन), MBR (मास्टर बूट रिकॉर्ड) या रुट विभाजन पर GRUB बूट लोड साधन पुनः इंस्टॉल करने हेतु साधन है। इसके द्वारा आप GRUB विन्यास फाइल का पुनः सृजन व MBR या PBR (रुट) को बैकअप एवं पुनः स्थापित कर सकते हैं।</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="58"/>
+        <location filename="ui_mainwindow.h" line="394"/>
         <source>What would you like to do?</source>
-        <translation type="unfinished"/>
+        <translation>आप क्या करना चाहेंगे?</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="79"/>
+        <location filename="ui_mainwindow.h" line="395"/>
         <source>Backup MBR or PBR (legacy boot only)</source>
-        <translation type="unfinished"/>
+        <translation>MBR या PBR का बैकअप (केवल पारंपरिक बूट)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="86"/>
+        <location filename="ui_mainwindow.h" line="396"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
-        <translation type="unfinished"/>
+        <translation>ESP, MBR या PBR (रुट) पर बूट लोड साधन का पुनः इंस्टॉल</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="96"/>
+        <location filename="ui_mainwindow.h" line="397"/>
         <source>Repair GRUB configuration file</source>
-        <translation type="unfinished"/>
+        <translation>GRUB विन्यास फाइल सुधार</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="103"/>
+        <location filename="ui_mainwindow.h" line="398"/>
         <source>Restore MBR or PBR from backup (legacy boot only)</source>
-        <translation type="unfinished"/>
+        <translation>बैकअप से MBR या PBR की पुनः स्थापना (केवल पारंपरिक बूट)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="136"/>
-        <location filename="mainwindow.cpp" line="485"/>
+        <location filename="mainwindow.cpp" line="483"/>
+        <location filename="ui_mainwindow.h" line="399"/>
         <source>Select Boot Method</source>
-        <translation type="unfinished"/>
+        <translation>बूट विधि चयन</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="154"/>
+        <location filename="ui_mainwindow.h" line="401"/>
         <source>Master Boot Record</source>
-        <translation type="unfinished"/>
+        <translation>मास्टर बूट रिकॉर्ड</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="157"/>
+        <location filename="ui_mainwindow.h" line="403"/>
         <source>MBR</source>
-        <translation type="unfinished"/>
+        <translation>MBR</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="160"/>
         <location filename="mainwindow.ui" line="430"/>
+        <location filename="ui_mainwindow.h" line="405"/>
+        <location filename="ui_mainwindow.h" line="426"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="182"/>
+        <location filename="ui_mainwindow.h" line="408"/>
         <source>Root (Partition Boot Record)</source>
-        <translation type="unfinished"/>
+        <translation>बूट (विभाजन बूट रिकॉर्ड)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="185"/>
-        <location filename="mainwindow.cpp" line="488"/>
+        <location filename="mainwindow.cpp" line="486"/>
+        <location filename="ui_mainwindow.h" line="410"/>
         <source>root</source>
-        <translation type="unfinished"/>
+        <translation>रुट</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="236"/>
-        <location filename="mainwindow.cpp" line="487"/>
+        <location filename="mainwindow.cpp" line="485"/>
+        <location filename="ui_mainwindow.h" line="411"/>
         <source>Install on:</source>
-        <translation type="unfinished"/>
+        <translation>यहाँ इंस्टॉल करें :</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="255"/>
-        <location filename="mainwindow.cpp" line="486"/>
+        <location filename="mainwindow.cpp" line="484"/>
+        <location filename="ui_mainwindow.h" line="412"/>
         <source>Location:</source>
-        <translation type="unfinished"/>
+        <translation>स्थान :</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="277"/>
-        <location filename="mainwindow.cpp" line="496"/>
+        <location filename="mainwindow.cpp" line="494"/>
+        <location filename="ui_mainwindow.h" line="416"/>
         <source>Select root location:</source>
-        <translation type="unfinished"/>
+        <translation>रुट स्थान चयन :</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="290"/>
+        <location filename="ui_mainwindow.h" line="418"/>
         <source>EFI System Partition</source>
-        <translation type="unfinished"/>
+        <translation>EFI सिस्टम विभाजन</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="293"/>
+        <location filename="ui_mainwindow.h" line="420"/>
         <source>ESP</source>
-        <translation type="unfinished"/>
+        <translation>ESP</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="420"/>
+        <location filename="ui_mainwindow.h" line="422"/>
         <source>About this application</source>
         <translation>इस अनुप्रयोग के बारे में</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="423"/>
+        <location filename="ui_mainwindow.h" line="424"/>
         <source>About...</source>
         <translation>बारे में...</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="472"/>
+        <location filename="ui_mainwindow.h" line="429"/>
         <source>Display help </source>
-        <translation>मदद देखें</translation>
+        <translation>सहायता देखें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="475"/>
+        <location filename="ui_mainwindow.h" line="431"/>
         <source>Help</source>
         <translation>सहायता</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="482"/>
+        <location filename="ui_mainwindow.h" line="433"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="523"/>
+        <location filename="ui_mainwindow.h" line="437"/>
         <source>Cancel any changes then quit</source>
-        <translation>बदलाव रद्द कर बंद करें</translation>
+        <translation>परिवर्तन रद्द कर बंद करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="526"/>
+        <location filename="ui_mainwindow.h" line="439"/>
         <source>Cancel</source>
         <translation>रद्द करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="533"/>
+        <location filename="ui_mainwindow.h" line="441"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="552"/>
+        <location filename="ui_mainwindow.h" line="444"/>
         <source>Apply any changes</source>
-        <translation type="unfinished"/>
+        <translation>परिवर्तन लागू करें</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="555"/>
-        <location filename="mainwindow.cpp" line="70"/>
+        <location filename="mainwindow.cpp" line="71"/>
+        <location filename="ui_mainwindow.h" line="446"/>
         <source>Apply</source>
         <translation>लागू करें</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="86"/>
+        <location filename="mainwindow.cpp" line="87"/>
         <source>GRUB is being installed on %1 device.</source>
-        <translation type="unfinished"/>
+        <translation>%1 उपकरण पर GRUB इंस्टॉल प्रक्रिया जारी।</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="118"/>
-        <location filename="mainwindow.cpp" line="203"/>
-        <location filename="mainwindow.cpp" line="312"/>
-        <location filename="mainwindow.cpp" line="394"/>
+        <location filename="mainwindow.cpp" line="110"/>
+        <location filename="mainwindow.cpp" line="130"/>
+        <location filename="mainwindow.cpp" line="192"/>
+        <location filename="mainwindow.cpp" line="216"/>
+        <location filename="mainwindow.cpp" line="322"/>
+        <location filename="mainwindow.cpp" line="396"/>
         <location filename="mainwindow.cpp" line="419"/>
-        <location filename="mainwindow.cpp" line="527"/>
-        <location filename="mainwindow.cpp" line="534"/>
-        <location filename="mainwindow.cpp" line="597"/>
+        <location filename="mainwindow.cpp" line="525"/>
+        <location filename="mainwindow.cpp" line="532"/>
+        <location filename="mainwindow.cpp" line="591"/>
         <source>Error</source>
         <translation>त्रुटि</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="119"/>
-        <location filename="mainwindow.cpp" line="204"/>
+        <location filename="mainwindow.cpp" line="110"/>
+        <location filename="mainwindow.cpp" line="192"/>
+        <source>Could not create a temporary folder</source>
+        <translation>अस्थायी फोल्डर बनाना विफल</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="130"/>
+        <location filename="mainwindow.cpp" line="216"/>
         <source>Could not set up chroot environment.
 Please double-check the selected location.</source>
-        <translation type="unfinished"/>
+        <translation>Chroot वातावरण सेट करना विफल।
+कृपया चयनित स्थान पुनः जाँचें।</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="179"/>
+        <location filename="mainwindow.cpp" line="189"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
-        <translation type="unfinished"/>
+        <translation>GRUB विन्यास फाइल (grub.cfg) का पुनः सृजन जारी।</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="222"/>
+        <location filename="mainwindow.cpp" line="233"/>
         <source>Backing up MBR or PBR from %1 device.</source>
-        <translation type="unfinished"/>
+        <translation>%1 उपकरण से MBR या PBR का बैकअप जारी।</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="287"/>
+        <location filename="mainwindow.cpp" line="297"/>
         <source>Warning</source>
         <translation>चेतावनी</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="298"/>
         <source>You are going to write the content of </source>
-        <translation type="unfinished"/>
+        <translation>आप द्वारा यह सामग्री राइट होगी</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="298"/>
         <source> to </source>
-        <translation type="unfinished"/>
+        <translation>यहाँ पर</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="298"/>
         <source>
 
 Are you sure?</source>
-        <translation type="unfinished"/>
+        <translation>
+
+क्या आप निश्चित हैं?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="293"/>
+        <location filename="mainwindow.cpp" line="303"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
-        <translation type="unfinished"/>
+        <translation>%1 उपकरण से MBR/PBR की पुनः स्थापना जारी।</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="313"/>
+        <location filename="mainwindow.cpp" line="322"/>
         <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
-        <translation type="unfinished"/>
+        <translation>सिस्टम डिस्क पर ESI सिस्टम विभाजन (ESP) हेतु खोज विफल। कृपया ESP सृजन कर पुनः प्रयास करें।</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="348"/>
+        <location filename="mainwindow.cpp" line="353"/>
         <source>Select %1 location:</source>
-        <translation type="unfinished"/>
+        <translation>%1 स्थान चुनें :</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="372"/>
+        <location filename="mainwindow.cpp" line="375"/>
         <source>Back</source>
-        <translation type="unfinished"/>
+        <translation>वापस</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="388"/>
+        <location filename="mainwindow.cpp" line="391"/>
         <source>Success</source>
         <translation>सफलता</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="389"/>
+        <location filename="mainwindow.cpp" line="392"/>
         <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit Boot Repair?&lt;/b&gt;</source>
-        <translation type="unfinished"/>
+        <translation>प्रक्रिया सफलतापूर्वक पूर्ण। &lt;p&gt;&lt;b&gt;क्या आप बूट सुधार बंद करना चाहते हैं?&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="395"/>
+        <location filename="mainwindow.cpp" line="396"/>
         <source>Process finished. Errors have occurred.</source>
-        <translation type="unfinished"/>
+        <translation>प्रक्रिया पूर्ण। त्रुटियाँ हुई हैं।</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="412"/>
+        <location filename="mainwindow.cpp" line="413"/>
         <source>Enter password to unlock %1 encrypted partition:</source>
-        <translation type="unfinished"/>
+        <translation>%1 एन्क्रिप्टेड विभाजन अभिगम हेतु कूटशब्द दर्ज करें :</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="420"/>
+        <location filename="mainwindow.cpp" line="419"/>
         <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="unfinished"/>
+        <translation>क्षमा करें, %1 LUKS कंटेनर खोलना विफल</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="495"/>
+        <location filename="mainwindow.cpp" line="493"/>
         <source>Select GRUB location</source>
-        <translation type="unfinished"/>
+        <translation>GRUB स्थान चयन</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="507"/>
+        <location filename="mainwindow.cpp" line="505"/>
         <source>Select Item to Back Up</source>
-        <translation type="unfinished"/>
+        <translation>बैकअप हेतु वस्तु चयन</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="514"/>
+        <location filename="mainwindow.cpp" line="512"/>
         <source>Select Item to Restore</source>
-        <translation type="unfinished"/>
+        <translation>पुनः स्थापना हेतु वस्तु चयन</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="523"/>
+        <source>Select backup file name</source>
+        <translation>बैकअप फाइल हेतु नाम चयन</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="525"/>
-        <source>Select backup file name</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="527"/>
-        <location filename="mainwindow.cpp" line="534"/>
-        <source>No file was selected.</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
         <location filename="mainwindow.cpp" line="532"/>
+        <source>No file was selected.</source>
+        <translation>कोई फाइल चयनित नहीं है।</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="530"/>
         <source>Select MBR or PBR backup file</source>
-        <translation type="unfinished"/>
+        <translation>MBR या PBR बैकअप फाइल चयन</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="552"/>
+        <location filename="mainwindow.cpp" line="550"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>%1 के बारे में</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="553"/>
+        <location filename="mainwindow.cpp" line="551"/>
         <source>Version: </source>
         <translation>संस्करण :</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="554"/>
+        <location filename="mainwindow.cpp" line="552"/>
         <source>Simple boot repair program for antiX Linux</source>
-        <translation type="unfinished"/>
+        <translation>एंटी-एक्स लिनक्स हेतु सरल बूट सुधार प्रोग्राम</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="556"/>
+        <location filename="mainwindow.cpp" line="554"/>
         <source>Copyright (c) MX Linux</source>
-        <translation>प्रतिलिप्याधिकार (c) MX Linux</translation>
+        <translation>कॉपीराइट (c) एमएक्स लिनक्स</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="557"/>
+        <location filename="mainwindow.cpp" line="555"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>%1 लाइसेंस</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="571"/>
+        <location filename="mainwindow.cpp" line="568"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>%1 सहायता</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="598"/>
+        <location filename="mainwindow.cpp" line="591"/>
         <source>Sorry, could not mount %1 partition</source>
-        <translation type="unfinished"/>
+        <translation>क्षमा करें, %1 विभाजन माउंट करना विफल</translation>
     </message>
 </context>
 <context>
@@ -337,12 +377,20 @@ Are you sure?</source>
     <message>
         <location filename="about.cpp" line="51"/>
         <source>&amp;Close</source>
-        <translation>&amp;बंद करें</translation>
+        <translation>बंद करें (&amp;C)</translation>
+    </message>
+</context>
+<context>
+    <name>QObject</name>
+    <message>
+        <location filename="main.cpp" line="57"/>
+        <source>Error</source>
+        <translation>त्रुटि</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="64"/>
-        <source>You must run this program as root.</source>
-        <translation>इस प्रोग्राम को चलाने हेतु आपका रुट होना आवश्यक है।</translation>
+        <location filename="main.cpp" line="58"/>
+        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
+        <translation>प्रतीत होता है कि आप रुट के रूप में लॉगिन हैं, प्रोग्राम उपयोग करने हेतु लॉगआउट कर सामान्य उपयोक्ता के रूप में लॉगिन करें।</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
